#
# spec file for package c-toxcore
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2013 Markus Kolb, Innsbruck, Austria.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines
%define _soversion 2
Name:           c-toxcore
Version:        0.2.13
Release:        bp153.2.3.1
Summary:        Secure decentralized instant messaging application
License:        GPL-3.0-only
Group:          Productivity/Networking/Instant Messenger
URL:            https://tox.chat/
Source0:        https://github.com/TokTok/c-toxcore/archive/v%{version}.tar.gz#./%{name}-%{version}.tar.gz
Source1:        %{name}.tmpfiles.d
Source2:        https://github.com/TokTok/c-toxcore/releases/download/v%{version}/%{name}-%{version}.tar.gz.asc
Source3:        %{name}.keyring
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libconfig-devel
BuildRequires:  libopus-devel
BuildRequires:  libsodium-devel
BuildRequires:  libtool
BuildRequires:  libvpx-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(systemd)
Requires(pre):  shadow
%{?systemd_requires}

%description
Project Tox, also known as Tox, is a FOSS instant messaging
application aimed to replace Skype.
With the rise of government monitoring programs,
Tox provides an easy to use application that allows you to connect
with friends and family without anyone else listening in.
While other big-name services require you to pay for features,
Tox is totally free and comes without advertising

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libtoxcore%{_soversion} = %{version}

%description devel
Development libraries and headers needed to build software using %{name}.

%package daemon
Summary:        Bootstrap-daemon for toxcore
Group:          Productivity/Networking/Instant Messenger

%description daemon
Bootstrap-daemon to dispose hashtable for toxcore.

%package -n libtoxcore%{_soversion}
Summary:        Core library for toxcore
Group:          System/Libraries

%description -n libtoxcore%{_soversion}
This are the Core library for toxcore.

%prep
%setup -q
# change location of bootstrap bin
sed -ri 's:%{_prefix}/local/bin/tox-bootstrapd:%{_bindir}/tox-bootstrapd:g' other/bootstrap_daemon/tox-bootstrapd.service
# change user and of bootstrapd
sed -ri 's:User=tox-bootstrapd:User=tox:g' other/bootstrap_daemon/tox-bootstrapd.service
sed -ri 's:Group=tox-bootstrapd:Group=toxcmd:g' other/bootstrap_daemon/tox-bootstrapd.service
# change location of bootstrap kyes
sed -ri 's:%{_localstatedir}/lib/tox-bootstrapd/keys:%{_sysconfdir}/tox/bootstrapd/keys:g' other/bootstrap_daemon/tox-bootstrapd.conf

%build
pushd build
cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} \
      -DBUILD_TOXAV=ON \
      -DMUST_BUILD_TOXAV=ON \
      -DBOOTSTRAP_DAEMON=ON \
      -DDHT_BOOTSTRAP=ON \
      -DENABLE_STATIC=OFF  \
      ..

make %{?_smp_mflags}
popd

%install
make install -C build PREFIX=%_prefix DESTDIR=%buildroot

# Install dir /var/run/graylog2-server
install -d -m 0755 %{buildroot}%{_prefix}/lib/tmpfiles.d/
install -m 0644 %{SOURCE1} %{buildroot}%{_prefix}/lib/tmpfiles.d/tox-bootstrapd.conf

# Install dir /var/lib/tox-bootstrapd
install -d -m 0755 %{buildroot}%{_localstatedir}/lib/tox-bootstrapd/
# Install dir /etc/tox/bootstrapd/keys
install -d -m 0700 %{buildroot}%{_sysconfdir}/tox/bootstrapd/keys

# Install dir /etc and bootstrap-config
mkdir -p %{buildroot}/%{_sysconfdir}
install -D -m 0640 other/bootstrap_daemon/tox-bootstrapd.conf %{buildroot}%{_sysconfdir}/tox/bootstrapd/tox-bootstrapd.conf

# Install init-scripts
mkdir -p %{buildroot}/%{_sbindir}
install -D -m 0644 other/bootstrap_daemon/tox-bootstrapd.service %{buildroot}%{_unitdir}/tox-bootstrapd.service
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rctox-bootstrapd

%pre daemon
%service_add_pre tox-bootstrapd.service
# create tox-bootstrapd group
if ! getent group toxcmd >/dev/null; then
        groupadd -r toxcmd
fi
# create tox-bootstrapd user
if ! getent passwd tox >/dev/null; then
        useradd -r -g toxcmd -d %{_localstatedir}/lib/tox-bootstrapd \
            -s /sbin/nologin -c "Tox Bootstrap" tox
fi

%post daemon
%service_add_post tox-bootstrapd.service
systemd-tmpfiles --create %{_prefix}/lib/tmpfiles.d/tox-bootstrapd.conf

%post -n libtoxcore%{_soversion} -p /sbin/ldconfig

%preun daemon
%service_del_preun tox-bootstrapd.service

%postun daemon
%service_del_postun tox-bootstrapd.service

%postun -n libtoxcore%{_soversion} -p /sbin/ldconfig

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%dir %{_includedir}/tox
%{_includedir}/tox/*

%files
%license LICENSE
%doc README.md DONATORS CHANGELOG.md

%files daemon
%dir %{_sysconfdir}/tox
%dir %{_sysconfdir}/tox/bootstrapd
%config(noreplace) %{_sysconfdir}/tox/bootstrapd/tox-bootstrapd.conf
%{_bindir}/DHT_bootstrap
%{_bindir}/tox-bootstrapd
%{_unitdir}/tox-bootstrapd.service
%{_tmpfilesdir}/tox-bootstrapd.conf
%{_sbindir}/rctox-bootstrapd
%dir %{_localstatedir}/lib/tox-bootstrapd
%dir %attr(0770,tox,toxcmd) %{_sysconfdir}/tox/bootstrapd/keys

%files -n libtoxcore%{_soversion}
%{_libdir}/libtoxcore.so.%{_soversion}*

%changelog
* Thu Dec  9 2021 Andrey Karepin <egdfree@opensuse.org>
- Fix boo#1193667
  - (CVE-2021-44847): A stack-based buffer overflow in handle_request
    function in DHT.c in toxcore allows remote attackers to crash
    the process or potentially execute arbitrary code via a network
    packet.
- Update to 0.2.13
  * Merged PRs:
  - #1725 cleanup: add some missing null checks
  - #1723 chore: Run infer static analyser on circle ci builds.
  - #1718 fix: Sec/fix crypto size compute
  - #1716 chore: Use toktok-stack docker image with built third_party.
  - #1713 test: Add some unit tests for important internal DHT functions.
  - #1708 perf: reduce calling into Mono_Time in DHT
  - #1706 chore: Enable cimple tests on cirrus build.
  - #1705 fix: issue with save_load autotest
  - #1703 chore: Upgrade to toktok-stack:0.0.11.
  - #1699 fix: some friend connection issues
  - #1698 fix: bug causing API to report wrong self connection status
  - #1693 chore: Update IRC info
  - #1691 chore: Fix Appveyor and add workarounds for Cirrus CI
  - #1686 chore: Enable c-toxcore conan packaging
  - #1684 cleanup: Update INSTALL.md instructions
  - #1679 cleanup: Trivial cleanup
  - #1674 cleanup: filetransfer code
  - #1672 docs: Add instructions for building unit tests to INSTALL.md
  - #1667 chore: Update tox-bootstrapd checksum due to newer packages in Alpine
  - #1664 cleanup: use heap memory instead of stack for large variables
  - #1663 fix: Fix file tests on windows
  - #1633 fix: AppVeyor failing due to conan remote being added twice
  - #1602 fix: Fix buffer over-read when a peer leaves a conference
  - #1586 test: Fix tcp_relay_test by adding a second bootstrap node.
  - #1580 style: Format comments according to tokstyle's requirements.
  - #1557 chore: Add conan support
  - #1537 chore: Cygwin build
  - #1516 cleanup: Make pylint and mypy happy with bootstrap_node_info.py.
  - #1515 style: Run restyled on Travis and Circle CI scripts.
  - #1514 refactor: Remove multi-declarators entirely.
  - #1513 refactor: Disallow multiple initialised declarators per decl.
  - #1510 chore: Don't build pushes to branches, only to tags.
  - #1504 chore: Remove release-drafter configuration in favour of global one.
  - #1498 refactor: Limit scope of loop iterators.
  - #1497 refactor: Use bash arrays instead of strings for static analysis scripts.
  - #1496 cleanup: Stop hard-coding packet IDs in tests.
  - #1495 chore: Exclude imported libsodium sources from restyled.
  - #1493 feat: Add logging to TCP and onion client.
  - #1489 cleanup: NAC_LIBS -> NACL_LIBS.
  - #1487 chore: Add autotools build to localbuild docker images.
  - #1473 chore: Add a script to run Travis CI locally.
  - #1467 fix: Fix a bug in savedata loading when malloc fails.
  - #1464 fix: Fix errors on error paths found by oomer.
  - #1463 cleanup: Add a check that we don't have any unused functions.
  - #1462 cleanup: Include <string.h> for explicit_bzero.
  - #1436 chore: Enable cimple tests by default but allow disabling them.
  * Closed issues:
  - #1598 ERROR: heap-buffer-overflow in group.c found with AddressSanitizer
  - #1326 the cause is great, but this thing is completely unusable
  - #1319 Is this new application is safe & trusted ??
  - #1236 Ruby Extension?
  - #1149 uTox aborts on toxcore restart
  - #886 Maybe need to set the stacksize for musl-libc
* Sun May 10 2020 ecsos <ecsos@opensuse.org>
- Update to 0.2.12
  * Merged PRs:
  - #1457 Disable non-hermetic tests by default.
  - #1456 Limit the number of friends you can have to ~4 billion.
  - #1452 Add execution trace option for debugging.
  - #1447 Udp dht group chats
  - #1444 Set up release-drafter to automatically draft the next release.
  - #1443 Allow test coverage to fluctuate 2%% up and down, but not below 80%%.
  - #1442 Add CODEOWNERS and settings.yml files.
  - #1441 [ImgBot] Optimize images
  - #1439 Fix continuous integration builds.
  - #1437 Rework the toxchat/bootstrap-node Docker image.
  - #1435 Enable TCP relay test in Bazel and autotools build.
  - #1434 Skip invalid TCP relays and DHT nodes when loading save data.
  - #1433 Fix saving of combination of loaded and connected TCP relays
  - #1430 Invert not_valid functions and name them is_valid.
  - #1429 Fix things not being initialized if creating a TCP-only network
  - #1426 Remove tokstyle exemptions from build files.
  - #1425 Stop using the "inline namespace" feature of apidsl.
  - #1424 Add new semi-private API functions to set per-packet-id custom handlers.
  - #1423 Give CI workflow a better name: clang-sanitizers
  - #1422 Use public API for sending in RTP
  - #1421 Install ci-tools and get tokstyle via the script it provides.
  - #1420 Use tox public API for sending packets in toxav BWController
  - #1419 Remove newlines from the end of LOGGER format strings.
  - #1418 Change ToxAVCall struct mutex to a more distinct name
  - #1417 Create own instance of Mono_Time for ToxAV
  - #1416 Stop using Messenger's mono_time in bandwidth controller.
  - #1415 Fix 2 memory leaks in ToxAV.
  - #1414 Show function names in asan/tsan stack traces on CircleCI.
  - #1413 Make afl_toxsave.c a bit more portable; fix memory leak.
  - #1411 Fixes towards building on MSVC.
  - #1409 Mark conference test as small.
  - #1407 Add minimal save generator
  - #1406 Migrate format-source script to new apidsl web app.
  - #1404 Smarter setup of bazel remote cache on Cirrus CI.
  - #1331 Add basic test adapter for AFL
  * Closed issues:
  - #1365 Add the option to use LAN discovery even when using a proxy for remote connections
  - #1353 libtoxdns.a and libtoxav.a
  - #86 Freenet as Offline Messaging Backend
* Mon Mar 23 2020 Andrey Karepin <egdfree@opensuse.org>
- update to 0.2.11
  * #1403 Install libsodium from apt instead of from source.
  * #1402 Remove bazel build from Travis.
  * #1400 Disable bazel remote cache on CI.
  * #1399 Periodically try to send direct packets when connected by TCP.
  * #1398 Minor cleanup: use assoc_timeout function where possible.
  * #1397 Check that LOGGER macros are only called with string literals.
  * #1396 Make function defns match their decls regarding storage class.
  * #1395 Mark file-local function definitions as static.
  * #1394 Enable remote cache for bazel builds.
  * #1393 Add another bootstrap node to the bootstrap test.
  * #1392 Clear out old conference connections.
  * #1391 Minor cleanups in network code.
  * #1390 Avoid casting back and forth between void-ptr.
  * #1389 Standardise on having a comma at the end of enums.
  * #1388 Fix up comments a bit to start being more uniform.
  * #1387 Use rules_cc instead of native cc_library rules.
  * #1386 Use spdx license identifier instead of GPL blurb.
  * #1383 Pass packet ID to custom packet handlers.
  * #1382 Add a mutex lock/unlock inside every public API function.
  * #1381 Use net_pack instead of casting bytes to ints.
  * #1380 Disable FreeBSD travis build until it is fixed.
  * #1379 Update and fix FreeBSD setup on Travis-CI
  * #1378 Use ninja build system for the cmake-linux build.
  * #1376 Remove testing/av_test.c.
  * #1375 Add "cimple_test" to the bazel build.
  * #1374 Handle invite to existing conference
  * #1372 Upgrade bazel to 2.1.1.
  * #1371 Bump to astyle-3.1 in travis build.
  * #1370 use -1 rather than ~0 in unsigned integer types
  * #1362 Workaround for message number saving
  * #1358 Allow Bazel to rerun tests marked as flaky
  * #1352 Update tests to use a working bootstrap node
  * #1349 Fix tox-bootstrapd's README and update Dockerfile
  * #1347 Fix pthread_mutex_destroy getting too many arguments
  * #1346 Fix most TSAN failures
  * #1345 fix concurrency issues in mono_time
  * #1343 Fix TSAN failures in tests
  * #1334 fix missing group title length check
  * #1330 Force IPv4 for cirrus-ci tests
  * #1329 bump libsodium version in appveyor.yml
  * #1322 Clean-up of group.c code
  * #1321 Some small fixes to groups.
  * #1299 Add VScode folder to .gitignore
  * #1297 Use net_pack/unpack instead of host_to_net.
  * #1373 handle crashes after group invites
  * #1368 Are tox clients also open source
  * #1366 Generate a link for websites (Friendship and proxy)
  * #1354 Unstable Tests
  * #1316 Documentation claims toxav_iteration_interval is threadsafe but it's not
  * #1274 build error
  * #850 GPG App Usage
* Wed Jun 26 2019 Andrey Karepin <egdfree@opensuse.org>
- update to 0.2.10
  * #1320 add undef guard in tox_many_tcp_test
  * #1314 Fix bazel build version at 0.22.0 for CI.
  * #1311 Disable failing TCP server test
  * #1310 Do not send the same packet to the same node twice
  * #1309 add configurable limit on number of stored frozen peers
  * #1305 Expose api functions for enabling and disabling AV in AV groups
  * #1302 Specify that buffer size for tox_conference_peer_get_name is given by $size
  * #1313 CirrusCI is failing and blocking PRs
  * #1312 Onion client review
  * #1306 Persistent conference's offline peer list always grows and never decreases
  * #1303 Loaded persistent groups fail to send audio
  * #1298 How to make libtox4j-c.so for android?
  * #1261 Bump so version
  * #1116 Message length is too large log spam
* Sun Jan 13 2019 Andrey Karepin <egdfree@opensuse.org>
- update to 0.2.9
  * #1296 Add some const qualifiers
  * #1295 Implement all min/max functions for (un)signed int types.
  * #1293 Fix misaligned 4-byte access in trace logging.
  * #1291 Use correct path to test log to cat on error.
  * #1290 Display build log for autotools build on failure.
  * #1289 Enable auto tests under STRICT_ABI if static libs are available.
  * #1288 Add MIN_LOGGER_LEVEL to the Circle CI builds.
  * #1287 Avoid sending group messages to a peer before we have its group number
  * #1284 Use new WineHQ Debian package repository key
  * #1282 Merge irungentoo/master back into toktok/master.
  * #1281 Allow unauthenticated wine packages in the Windows build.
  * #1278 Add cmake option for building additional tests
  * #1277 Define tox_conference_id_size and tox_conference_uid_size
  * #1273 Avoid format truncation in save compatibility test
  * #1272 Upgrade bazel to 0.19.0 to fix the bazel build.
  * #1271 Return TOX_ERR_CONFERENCE_SEND_MESSAGE_NO_CONNECTION if we are not connected to any peers
  * #1268 Fix indices calculation for congestion control.
  * #1267 Improve handling of peers entering and leaving conferences
  * #1266 Expose offline conference peers in API
  * #1242 Fix critical stack overflow arising from VLA usage
  * #1239 Add some hopefully helpful documentation to the functions in mono_time.h
  * #1235 Change method of PK production for FAKE friend in DHT
  * #1234 Increase NOFILE limit for tox-bootstrapd
  * #1231 Use bool for IPv6 flag in test programs and DHT_bootstrap.
  * #1230 Add LOGGER_ASSERT for checking fatal error conditions.
  * #1229 Include CTest in CMakeLists.txt to get valgrind support.
  * #1228 Consistently use camel case enum names.
  * #1223 Add AUTOTEST option to CMakeLists.txt
  * #1221 Make tox-bootstrapd free memory on SIGINT and SIGTERM
  * #1218 Support DragonFlyBSD and prune unused variables.
  * #1215 Ensure save data unchanged after save and load
  * #1213 Make saving and loading the responsibility of Tox rather than Messenger
  * #1211 Some improvements to tox-bootstrapd's Dockerfile
  * #1210 Remove Alpine Linux bootstrap daemon dockerfile.
  * #1209 Improve Windows compatibility of toxav code.
  * #1206 Add LAN_discovery to the list of apidsl-generated files.
  * #1156 conferences saving
  * #1285 Persistent group titles get mixed up
  * #1276 How to run test case?
  * #1264 tox_conference_id_size() symbol missing
  * #1262 Fails to build with STRICT_ABI option
  * #1169 PK should not be generated with random_bytes
  * #1143 Test #1081
  * #956 friendlist access (add, delete, ...) causes crashes sometimes
  * #777 Proposal: TFCL [Tox Friend Capabilities Level]
  * #762 packet ranges not very clearly explained
  * #743 Proposal: reduce Video corruption even more by negotating the reference frame between sender and receiver
  * #735 Proposal: Tox MessageV2
  * #663 libvpx vulnerability
  * #626 please add documentation to: bwcontroller.c
  * #625 function names misleading in ToxAV
  * #617 WIP: ToxIdenticon - howto
  * #610 PACKET_LOSSY_AV_RESERVED 8 # why?
  * #609 payload_type hardcoded
  * #589 running a normal tox node as tcp relay is not possible
  * #584 [INFO]: network graphs 0.1.9 vs 0.1.10
  * #548 toxcore removes message receipts and filetransfers from memory, when client has short network outage
  * #375 Invalid bit rate prevents call
* Mon Oct  8 2018 Andrey Karepin <egdfree@opensuse.org>
- update to 0.2.8
  * #1224 Avoid use of IPv6 in tests if not supported (e.g. on Travis).
  * #1216 Fix memleak in tcp server by wiping priority queues on deletion
  * #1212 Fix logger level defaulting to TRACE in CMake
  * #1208 Remove a function-like macro and replace it with a function.
  * #1205 Use a working DHT node for bootstrap tests.
  * #1203 Revert "Improve cmake build for MSVC."
  * #1202 Reset onion search rate for a friend when we see evidence that they are online
  * #1199 Run tests on Appveyor (Windows native build).
  * #1198 Add Cirrus CI configuration.
  * #1197 Use new @pthread library from toktok-stack for Windows compat.
  * #1196 Run UBSAN (undefined behaviour sanitizer) on Circle CI.
  * #1195 Fix using uninitialized mutex on call end
  * #1192 Send rejoin packets on conference disconnection
  * #1191 Improve cmake build for MSVC
  * #1188 Fix yamllint test (it's gone from bazel, add a new one).
  * #1187 Fix typos in comments and log and test assertion messages.
  * #1165 Fixed a silly boolean practice using uint8_t
  * #1164 Format yaml files according to yamllint's requirements and remove branch filter for appveyor.
  * #1161 Use most recent version of Bazel (0.17.1).
  * #1158 Use C++ style casts in C++ code.
  * #1157 Use run_auto_test fixture in typing_test.c
  * #1155 Standardise header guards.
  * #1154 Assert that we don't kill tox before killing toxav.
  * #1153 Always use the passed logger (from Messenger) in msi_kill.
  * #1151 Fix typo: tcp_replays -> tcp_relays.
  * #1150 Use (void) for empty parameter lists in C.
  * #1147 Ignore "unused-result" warning in super_donators code.
  * #1145 Fix login issue on Travis-CI FreeBSD build
  * #1141 Include necessary opencv2 header on OSX.
  * #1140 Clean up add_to_list function a bit.
  * #1139 Avoid recursion in ip_is_lan and ip_is_local.
  * #1138 Add tool to find directly recursive calls in toxcore.
  * #1136 Remove the use of CLOCK_MONOTONIC_RAW.
  * #1135 Avoid use of global mutable state in mono_time on win32.
  * #1134 Use code font for tool names and flags in INSTALL.md.
  * #1126 Simplify configure.ac for faster autotools build.
  * #1095 Use test clock in run_auto_test tests and dht test
  * #1069 Add mechanism for recovering from disconnections in conferences
  * #1046 Finish the messenger state plugin system
  * #895 Feature bootstrap trace/debug log output
  * #1201 Windows cross-compilation is broken
  * #961 Can't send messages in persistent group chat
  * #960 Persistent groups don't work properly when using toxync bot
  * #838 How to get groupchat identifier?
* Sat Sep  1 2018 Ismail Dönmez <idonmez@suse.com>
- Fix license file name
- Fix filelist (add DHT_bootstrap)
* Sat Sep  1 2018 Andrey Karepin <egdfree@opensuse.org>
- update to 0.2.7
  * #1137 Make ip_is_lan return bool instead of 0/-1.
  * #1133 Make the tsan build fail instead of swallowing its errors.
  * #1132 Use bool in place of 0/1 int values.
  * #1131 Format crypto_core.c.
  * #1130 Fix test class name for mono_time_test.
  * #1129 Call abort instead of exit on test failure.
  * #1128 Add some tests for ping_array.
  * #1127 Update copyright to 2018.
  * #1125 Run save_compatibility_test in the autotools build.
  * #1124 Fix the PORT_ALLOC failure of save_compatibility_test.
  * #1123 Add support for setting a custom monotonic time function in mono_time
  * #1122 Run all tests (and compilation) in parallel with autotools.
  * #1120 Stop using massive macros in toxav_basic_test.
  * #1119 Use do-while instead of while in tests.
  * #1117 Fix leave callback calling in del_groupchat
  * #1112 Fix auto_tests Makefile
  * #1110 Add check to make sure tox was created successfully
  * #1109 Consistently use 'mono_time' rather than 'monotime'
  * #1107 Always print output on failure in cmake tests on Travis.
  * #1106 Fix libmisc_tools building
  * #1104 Avoid redefining macros from different files.
  * #1103 Upload coverage to codecov as well as coveralls.
  * #1102 Enable color diagnostics on circleci.
  * #1101 Make the save_compatibility_test work with bazel.
  * #1100 Make Mono_Time an argument to current_time_monotonic
  * #1099 Fix const cast in save-generator.
  * #1098 Run both asan and tsan on Circle CI.
  * #1097 Run project tests like yamllint_test.
  * #1096 Enable .travis.yml check and use non-markdown license.
  * #1094 Set _POSIX_C_SOURCE to 200112L. We need it for C99 compat.
  * #1092 Install the DHT_bootstrap binary on make install.
  * #1086 Try ipv6 connections even after udp timeout
  * #1081 Change while-loop to for-loop to express for-each-frame.
  * #1075 Fix FreeBSD VM on Travis not shutting down
  * #1061 Force storing the result of crypto_memcmp in the test.
  * #1057 Reduce the number of times unix_time_update is called.
  * #1051 Add save file generator, compatibility test, and generate a savefile
  * #1038 Use per-instance Mono_Time instead of a global unix_time
* Fri Aug 17 2018 egdfree@opensuse.org
- update to 0.2.6
  * #1090 Fix possible resource leaks in test
  * #1089 Limit the size of a save file in file_saving_test.
  * #1088 Use --config to tell bazel about the environment.
  * #1085 Prune long long warnings.
  * #1084 Fix style in toxav.c.
  * #1083 Fix coding style in rtp module.
  * #1082 Fix groupav.c style and avoid casts in toxav_old.c.
  * #1080 Fix memory leak in error path in group A/V.
  * #1079 Fix style in video.c.
  * #1078 Fix style in msi.c.
  * #1077 Make conferences_object properly typed.
  * #1076 Fix style in bwcontroller module.
  * #1074 Move OSX to stage 1 of Travis.
  * #1073 Stop running tests in the bazel build.
  * #1072 Avoid forward declaration of rtp structs.
  * #1071 Temporarily disable FreeBSD build, since it times out.
  * #1070 Fix enumerator names in toxav to comply with toxcore naming standards.
  * #1068 Fix a few warnings from clang.
  * #1067 Remove last use of the MIN macro.
  * #1066 Remove all uses of the PAIR macro in toxav.
  * #1064 Fix ToxAv's use of struct Tox.
  * #1063 Avoid passing -1 as friend connection to new groups.
  * #1062 Check that the save file size isn't larger than our address space.
  * #1060 Avoid implicit conversion of negative value to uint32_t.
  * #1059 Assert that we don't divide by 0 in random_testing.cc.
  * #1056 Fix typo in loop over assocs.
  * #1053 Use tokstyle in the cmake travis build.
  * #1049 Fix some printf format specifiers.
  * #1043 Add simple deterministic random number generator for tests
  * #1042 Add callback for successful connection to a conference
  * #1039 Use the crypto random functions instead of rand().
  * #1036 Add deprecation notice to some UPPER_CASE enums.
  * #1016 Split out conference type (text/av) from identifier.
* Wed Aug  8 2018 egdfree@opensuse.org
- update to 0.2.5
  * #1048 Fix error message in m_send_generic_message
  * #1047 Remove unused m_callback_log function.
  * #1041 Avoid multiple for-next expressions.
  * #1037 Run all tests in the Autotools build
  * #1035 Fix problems with initial connections and name-setting in conferences
  * #1032 Use auto_test fixture in some tests and standardise filenames
  * #1030 Make a separate struct Tox containing the Messenger.
  * #1029 Add by_id and get_id functions, renaming from *_uid.
  * #1025 More fixed_width ints and incorporating file_saving_test.c
  * #1023 Run buildifier on c-toxcore BUILD files.
  * #1022 Make resize in list.c return bool instead of 0/1.
  * #1021 Remove redundant casts to the same type.
  * #1020 Add github usernames to TODOs.
  * #1019 Synchronise parameter names in headers with those in the implementation.
  * #1018 Reduce nesting by doing more early returns on error.
  * #1017 Add missing braces in dht_test.c.
  * #1011 Run Clang global static analysis on Travis.
  * #1010 Avoid implementations in .h files or #including .c files.
  * #1028 qTox crashes 1-2 times a day after update to 0.2.4
  * #1002 Implement an abstraction over pthread and windows thread synchronisation primitives
* Sat Jul 21 2018 egdfree@opensuse.org
- update to 0.2.4
  * #1014 Use string comparison operator in configure.ac.
  * #1013 Link -lsocket and -lnsl for socket functions on Solaris.
  * #1012 Correct the max hostname length constant.
  * #1009 Using stdint instead of int/long
  * #1008 Set _XOPEN_SOURCE to 700 for FreeBSD.
  * #1007 Use enums for group packet types.
  * #1006 Set C++11/C99 flag manually in older cmake on not-msvc.
  * #1005 Use the correct repository name in the coverage badge.
  * #1003 Remove LOGGER_ERROR for harmless send failure.
  * #1001 Add conference_by_uid and conference_get_uid functions.
  * #1000 Limit number of group chats to 65536.
  * #998 Use named function types for group callbacks.
  * #997 Style fixes in TCP code; remove MIN and PAIR from util.h.
  * #996 Add the bazel build as one of the PR blocking builds.
  * #995 Fix style in some header files.
  * #994 Fix style in DHT.c.
  * #993 Move load_state and its helper functions to their own module.
  * #991 Use named function types for friend_connection callbacks.
  * #990 Use named function types for friend_requests callbacks.
  * #989 Use named function types for callbacks in net_crypto.
  * #987 Use named types for onion callbacks.
  * #986 Simplify Travis-CI FreeBSD build
  * #985 Clarify the intent of "file kinds" in the API.
  * #984 Avoid side-effectful assignments in conditionals.
  * #981 Factor out time keeping code into its own module: mono_time.c.
  * #979 Add a thread-safe version of unix_time and friends.
  * #978 Rename BS_LIST to BS_List to follow the naming conventions.
  * #977 Remove VLA usage from send_audio_packet.
  * #976 Call the "peer leaves" callback only once on group delete.
  * #975 Factor out the actual test code from conference_test.
  * #972 Add a test that reproduces the NULL peer nick bug.
  * #968 Make tox.c unambiguously parseable.
  * #967 lan_discovery_test and version_test cleanup
  * #966 Use run_auto_test.h test fixture for some auto-tests.
  * #965 Add #include <cstdio> for std::printf.
  * #964 Add some tests for our ring_buffer implementation.
  * #962 Collect PACKET_ID* constants in net_crypto.h, cleanup their uses
  * #958 Fix leak of Logger instances in dht_test.
  * #957 Remove broken conference tests.
  * #955 Another TCP_test upgrade
  * #954 Proposal: Make arg host understand clearly.
  * #953 Add missing MAX_HOSTNAME_LENGTH doc.
  * #945 Add a test to try and overflow the send queue in net_crypto.
  * #943 Correct check for net_crypto packet index.
  * #942 Simplify Travis CI builds.
  * #932 Various minor cleanups in net_crypto.
  * #1015 Improve Solaris support
  * #1004 qTox: "Program received signal SIGPIPE, Broken pipe." with TokTok-c-toxcore-v0.2.3_GH0 on FreeBSD 11.x.
  * #988 Registration on https://nodes.tox.chat (question)
  * #982 Merge the two travis stages for freebsd back into one
  * #970 Crash with persistent groups
  * #963 ToxAV's rb_write function is written in a strange way
  * #946 [API] for max proxy address length
  * #944 How detect that friend is busy
  * #936 Help needed in testing a tox client,I need some dummy toxids to test .
  * #923 Crash on malloc in ping_array_add
  * #911 Weekly Tox Dev Meeting
  * #910 Crash in clear_entry in ping_array.c
  * #903 c-toxcore and LGPL (question)
  * #528 c-toxcore on Windows can be compiled using MSYS2 (with modern MinGW-w64)
  * #450 Run format-test earlier in the build
  * #429 Cannot build on Windows using MinGW
* Fri Jul 13 2018 egdfree@opensuse.org
- add c-toxcore.keyring file
* Thu Jun 28 2018 egdfree@opensuse.org
- update to 0.2.3
  * #951 Only run astyle if the astyle binary exists.
  * #950 Remove utils.c and utils.h from toxencryptsave build.
  * #949 Fixes to the imported sodium sources to compile without warnings.
  * #948 Add a MAX_HOSTNAME_LENGTH constant.
  * #947 Remove the format test.
  * #937 Add new Circle CI configuration.
  * #935 Add a test for double conference invite.
  * #933 Add Logger to various net_crypto functions, and add const to Logger where possible.
  * #931 Avoid conditional-uninitialised warning for tcp test.
  * #930 Disable UDP when proxy is enabled.
  * #928 Use clang-format for C++ code.
  * #927 Add assertions to bootstrap tests for correct connection type.
  * #926 Make NULL options behave the same as default options.
  * #925 Add tests for what happens when passing an invalid proxy host.
  * #924 Make the net_crypto connection state an enum.
  * #922 Clarify/Improve test_some test
  * #921 Beginnings of a TCP_test.c overhaul
  * #920 Add test for creating multiple conferences in one tox.
  * #918 Merge irungentoo/master into toktok
  * #917 Add random testing program.
  * #916 Fix linking with address sanitizer.
  * #915 Remove resource_leak_test.
  * #914 Make dht_test more stable.
  * #913 Minor cleanup: return early on error condition.
  * #906 Sort bazel build file according to buildifier standard.
  * #905 In DEBUG mode, make toxcore crash on signed integer overflow.
  * #902 Log only the filename, not the full path in LOGGER.
  * #899 Fix macOS macro because of GNU Mach
  * #898 Fix enumeration of Crypto_Connection instances
  * #897 Fix ipport_isset: port 0 is not a valid port.
  * #894 Fix logging related crash in bootstrap node
  * #893 Fix bootstrap crashes, still
  * #892 Add empty logger to DHT bootstrap daemons.
  * #887 Fix FreeBSD build on Travis
  * #884 Fix the often call of event tox_friend_connection_status
  * #883 Make toxcore compile on BSD
  * #878 fix DHT_bootstrap key loading
  * #877 Add minitox to under "Other resources" section in the README
  * #875 Make bootstrap daemon use toxcore's version
  * #867 Improve network error reporting on Windows
  * #841 Only check full rtp offset if RTP_LARGE_FRAME is set
  * #823 Finish @Diadlo's network Family abstraction.
  * #822 Move system header includes from network.h to network.
* Wed May 16 2018 ecsos@opensuse.org
- switch building from autotools to cmake, so uTox can build.
  See https://github.com/uTox/uTox/issues/1205
* Wed Apr 18 2018 ecsos@opensuse.org
- update to 0.2.2
  - #872 Restrict packet kinds that can be sent through onion path.
  - #864 CMake warn if libconfig not found
  - #863 Remove broken and unmaintained scripts.
  - #859 Add clarifying comment to cryptpacket_received function.
  - #857 Avoid the use of rand() in tests.
  - #846 Disallow stderr logger by default.
  - #845 Fix coveralls reporting.
  - #844 Add COVERAGE cmake flag for clang.
  - #825 Add default stderr logger for logging to nullptr.
  - #824 Simplify sendpacket function, deduplicate some logic.
  - #809 Remove the use of the 'hh' format specifier.
  - #801 Add logging to the onion_test.
  - #797 Move struct DHT_Friend into DHT.c.
* Sun Apr  8 2018 ecsos@opensuse.org
- fix build failure for Leap 42.3
* Sun Apr  1 2018 sleep_walker@opensuse.org
- dependency cleanup
- get rid of static libraries completely
- disable ldconfig for non-libraries packages
* Thu Mar 22 2018 sleep_walker@opensuse.org
- fix license file name, put into %%license section
- drop libtoxdns subpackage
- get rid of libtool files
- add GPG signature of the sources
- fix source file name
* Tue Mar 20 2018 ecsos@opensuse.org
- update to 0.2.1
  * Merged PRs:
  - #837 Update version to 0.2.1.
  - #833 Add missing tox_nospam_size() function
  - #832 Don't set RTP_LARGE_FRAME on rtp audio packets
  - #831 Don't throw away rtp packets from old Toxcore
  - #828 Make file transfers 50%% faster.
- changes from 0.2.0
  * Merged PRs:
  - #821 Remove deprecated conference namelist change callback.
  - #820 Fix auto_tests to stop using the deprecated conference
    API.
  - #819 Change default username to empty string
  - #818 Change README to talk about cmake instead of autoreconf.
  - #817 Fix warning on Mac OS X and FreeBSD.
  - #815 Some minor cleanups suggested by cppcheck.
  - #814 Fix memory leak of Logger instance on error paths.
  - #813 Minor cleanups: dead stores and avoiding complex macros.
  - #808 Fix a bunch of compiler warnings and remove
    suppressions.
  - #807 Link all tests to the android cpufeatures library if
    available.
  - #806 Fix toxcore.pc generation.
  - #805 Add an option that allows us to specify that we require
    toxav.
  - #804 Fix OSX tests: find(1) doesn't work like on Linux.
  - #803 Fix the windows build: pthread needs to be linked after
    vpx.
  - #800 Make group number in the toxav public API uint32_t
  - #799 Implement the "persistent conference" callback changes
    as new functions.
  - #798 Add deprecation notices to functions that will go away
    in v0.3.0.
  - #796 Make some sizeof tests linux-only.
  - #794 Remove apidsl from the build.
  - #793 Add a bazel test that ensures all our projects are
    GPL-3.0.
  - #792 Increase range of ports available to Toxes during tests
  - #791 Run all tests in parallel on Travis.
  - #790 Disable lan discovery in most tests.
  - #789 Remove tox_test from autotools build.
  - #788 Don't print trace level logging in tests.
  - #787 Split up tox_test into multiple smaller tests
  - #783 Send 0 as peer number in CHANGE_OCCURRED group event.
  - #782 Use const more in C code.
  - #781 Don't build all the small sub-libraries.
  - #780 Get rid of the only GNU extension we used.
  - #779 Remove leftover symmetric key from DHT struct.
  - #778 Add static asserts for all the struct sizes in toxcore.
  - #776 Optionally use newer cmake features.
  - #774 Improve gtest finding, support local checkout.
  - #773 Add gtest include directory to -I flags if found.
  - #772 Reject discovery packets coming from outside the "LAN".
  - #771 Adopt the "change occurred" API change from
    isotoxin-groupchat.
  - #770 Add MSVC compilation instructions
  - #767 Build toxcore with libsodium.dll instead of
    libsodium.lib.
  - #766 Remove libcheck from the dependencies.
  - #764 Fix LAN discovery on FreeBSD.
  - #760 Make cmake script more forgiving.
  - #759 Use more ubuntu packages; remove hstox for now.
  - #757 Improve stability of crypto_memcmp test.
  - #756 Format .cpp files with format-source.
  - #755 Add some unit tests for util.h.
  - #754 Move the tox_sync tool to the toxins repository.
  - #753 Move irc_syncbot to the toxins repository.
  - #752 Move tox_shell program to the toxins repository.
  - #751 Use the markdown GPLv3 license in the c-toxcore repo.
  - #750 Remove csrc from the RTPHeader struct.
  - #748 Revert "Add correction message type"
  - #745 Change the "capabilities" field to a "flags" field.
  - #742 Improve conference test stability.
  - #741 Add -D__STDC_LIMIT_MACROS=1 for C++ code.
  - #739 Add RTP header fields for the full frame length and
    offset.
  - #737 Use nullptr as NULL pointer constant instead of NULL
    or 0.
  - #736 Avoid clashes with "build" directories on
    case-insensitive file systems.
  - #734 Make audio/video bit rates "properties"
  - #733 Fix link in README.md
  - #730 Fix out of bounds read in error case in messenger_test.
  - #729 Remove dead return statement.
  - #728 Disable the autotools build in PR builds.
  - #727 Rename some rtp header struct members to be clearer.
  - #725 Publish a single public BUILD target for c-toxcore.
  - #723 Use <stdlib.h> for alloca on FreeBSD.
  - #722 Use self-built portaudio instead of system-provided.
  - #721 Manually serialise RTPHeader struct instead of memcpy.
  - #718 Improve sending of large video frames in toxav.
  - #716 Add comment from #629 in ring_buffer.c.
  - #714 Make BUILD files more finely-grained.
  - #713 Add BUILD files for all the little tools in the repo.
  - #711 Make the monolith test a C++ binary.
  - #710 Don't allocate or dereference Tox_Options in tests.
  - #709 Remove nTox from the repo.
  - #708 Add testing/*.c (except av_test) to bazel build.
  - #707 Fix log message in simple_conference_test:
    invite -> message.
  - #703 Add a simple conference test with 3 friends.
  - #701 Add astyle to Circle CI build.
  - #700 Use more descriptive names in bwcontroller.
  - #699 Add some explanatory comments to the toxav audio code.
  - #698 Extract named constants from magic numbers in
    toxav/audio.c.
  - #697 Use C99 standard in bazel builds.
  - #694 Add bazel build scripts for c-toxcore.
  - #693 Make libcheck optional for windows builds.
  - #691 Don't install packages needlessly on Travis
  - #690 Run fewer Travis jobs during Pull Requests.
  - #689 Make Net_Crypto a module-private type.
  - #688 Make DHT a module-private type.
  - #687 Use apidsl to generate LAN_discovery.h.
  - #686 Remove hstox test for now.
  - #685 Add message type for correction
  - #684 Add random_u16 function and rename the others to match.
  - #682 Use larger arrays in crypto timing tests.
  - #681 Fix some memory or file descriptor leaks in test code.
  - #680 Filter out annoying log statements in unit tests.
  - #679 Use apidsl to generate ping.h.
  - #678 Sort monolith.h according to ls(1): uppercase first.
  - #677 Make pack/unpack_ip_port public DHT functions.
  - #675 Make Onion_Announce a module-private type.
  - #674 Make TCP_Client_Connection a module-private type.
  - #673 Move TCP_Secure_Connection from .h to .c file.
  - #672 Make Friend_Connections a module-private type.
  - #670 Make Friend_Requests a module-private type.
  - #669 Make Onion_Client a module-private type.
  - #668 Make Ping_Array a module-private type.
  - #667 pkg-config .pc files: added .private versions of Libs
    and Required
  - #665 Remove useless if statement
  - #662 Move Networking_Core struct into the .c file.
  - #661 Disable asan, since it seems to break on travis.
  - #660 Increase test retries to 10 (basically infinite).
  - #659 Fix formatting in some C files.
  - #658 Call freeaddrinfo on error paths in net_getipport.
  - #657 Zero-initialise stack-allocated objects in hstox driver.
  - #656 Fix file descriptor leak in hstox test.
  - #652 Add support for building the monolith test on android.
  - #650 Remove deprecated ToxDNS
  - #648 Make hstox compile on FreeBSD
  - #624 Update rpm spec and use variables in cmake instead of
    hardcoded paths
  - #616 Add projects link to Readme.
  - #613 Fix travis
  - #605 Fix OS X Travis.
  - #598 Fix typos in docs
  - #578 Split toxav_bit_rate_set() into two functions to hold
    the maximum bitrates libvpx supports
  - #477 Update install instructions to use CMake
  - #465 Add Alpine linux Dockerfile in addition to the existing
    Debian one
  - #442 Generate only one large library "libtoxcore".
  - #334 Change toxencryptsave API to never overwrite pass keys.
  * Closed issues:
  - #704 Add CORRECTION support to group chats
  - #620 Video bug: large video frames are not sent correctly
  - #606 groupId is int whereas friendId is uint32_t, reason?
  - #572 int32_t may be not large enough as a argument for
    video_bit_rate of vp8/9 codec
  - #566 LAYER #: modules for static linking - build issue
  - #42 Remove ToxDNS and related stuff from toxcore
* Wed Dec 27 2017 sleep_walker@opensuse.org
- rename from toxcore to c-toxcore
- update to 0.1.11
  * Merged PRs:
  - #643 Add .editorconfig
  - #637 Update tox-bootstrapd Dockerfile
  - #635 Separate FreeBSD Travis build in 2 stages
  - #632 Lift libconfig to v1.7.1
  - #631 Add aspcud for Opam
  - #630 Fix for Travis fail on addr_resolve testing
  - #623 Split video payload into multiple RTP messages when too
    big to fit into one
  - #615 forget DHT pubkey of offline friend after DHT timeout
  - #611 Fix typo
  - #607 set onion pingid timeout to announce timeout (300s)
  - #592 Adjust docs of few toxencrypt function to the code
  - #587 Fix tox test
  - #586 Improve LAN discovery
  - #576 Replace include(CTest) on enable_testing()
  - #574 Reset hole-punching parameters after not punching for
    a while
  - #571 Configure needs to find libsodium headers.
  - #515 Network cleanup: reduce dependency on system-defined
    constants
  - #505 Add FreeBSD Travis
  - #500 Fixed the bug when receipts for messages sent from the
    receipt callback never arrived.
  * Closed issues:
  - #493 Receipts for messages sent from the receipt callback
    never arrive
- drop msi.c_no-return-in-nonvoid-function.patch
* Wed Aug 30 2017 ecsos@opensuse.org
- update to 0.1.10
  * Merged PRs:
  - #564 Fix Windows build
  - #542 Save bandwidth by moderating onion pinging
* Sun Jun 11 2017 ecsos@opensuse.org
- update to 0.1.9
  * Merged PRs:
  - #561 Remove unused variable
  - #560 Fix non-portable zeroing out of doubles
  - #559 Fix theoretical memory leaks
  - #557 Document inverted mutex lock/unlock.
  - #556 Build tests on appveyor, the MSVC build, but don't run
    them yet.
  - #555 Fold hstox tests into the general linux test.
  - #554 Add a monolith_test that includes all toxcore sources.
  - #553 Factor out strict_abi cmake code into a separate module.
  - #552 Fix formatting and spelling in version-sync script.
  - #551 Forbid undefined symbols in shared libraries.
  - #546 Make variable names in file saving test less cryptic
  - #539 Make OSX test failures fail the Travis CI build.
  - #537 Fix TokTok/c-toxcore#535
  - #534 Fix markdown formatting
  - #530 Implement missing TES constant functions.
  - #511 Save bandwidth by avoiding superfluous Nodes Requests to
    peers already on the Close List
  - #506 Add test case for title change
  - #498 DHT refactoring
  - #487 Split daemon's logging backends in separate modules
  - #468 Test for memberlist not changing after changing own name
  - #449 Use new encoding of Maybe in msgpack results.
  * Closed issues:
  - #482 CMake can't detect and compile ToxAV on OSX
* Mon May  1 2017 ecsos@opensuse.org
- update to 0.1.8
  * Closed issues:
  - #535 OS X tests failing
  - #503 Undefined functions: tox_pass_salt_length,
    tox_pass_key_length, tox_pass_encryption_extra_length
  - #456 Tox.h doesn't expose the size of the nospam.
  - #411 Reduce CTest timeout to 2 minutes
  * Merged PRs:
  - #538 Reverting tox_loop PR changes
  - #526 Add TOX_NOSPAM_SIZE to the public API.
  - #525 Retry autotools tests the same way as cmake tests.
  - #524 Reduce ctest timeout to 2 minutes from 5 minutes.
  - #512 Add test for DHT pack_nodes and unpack_nodes
  - #504 CMake: install bootstrapd if it is built
  - #488 Save compiled Android artifacts after CircleCI builds.
  - #473 Added missing includes: <netinet/in.h> and
    <sys/socket.h>
  - #335 Implement tox_loop
- update to 0.1.7
  * Closed issues:
  - #482 CMake can't detect and compile ToxAV on OSX
  * Merged PRs:
  - #521 Fix appveyor script: install curl from chocolatey.
  - #510 Fix list malloc(0) bug
  - #509 Fix network malloc(0) bug
  - #497 Fix network
  - #496 Fix Travis always succeeding despite tests failing
  - #491 Add crypto_memzero for temp buffer
  - #490 Move c_sleep to helpers.h and misc_tools.h
  - #486 Remove empty line in Messenger.c
  - #483 Make BUILD_TOXAV an option and fail if dependencies are
    missing
  - #481 Remove dependency on strings.h
  - #480 Use VLA macro
  - #479 Fix pthreads in AppVeyor build
  - #471 Remove statics used in onion comparison functions.
  - #461 Replace part of network functions on
    platform-independent implementation
  - #452 Add VLA compatibility macro for C89-ish compilers.
* Sun Feb  5 2017 ecsos@opensuse.org
- update to 0.1.6
  * Closed issues:
  - #415 Set up a native windows build on appveyor
  - #124 Don't include OS specific headers in .h files
  * Merged PRs:
  - #460 Release v0.1.6.
  - #454 Add appveyor build for native windows tests.
  - #448 Only retry failed tests on Circle CI instead of all.
  - #434 Replace redundant packet type check in handler with
    assert.
  - #432 Remove some static variables
  - #385 Add platform-independent Socket and IP implementation
- update to 0.1.5
  * Merged PRs:
  - #447 Release v0.1.5.
  - #446 Limit number of retries to 3.
  - #445 Make Travis tests slightly more robust by re-running
    them.
  - #443 Make building DHT_bootstrap in cmake optional.
  - #433 Add tutorial and "danger: experimental" banner to
    README.
  - #431 Update license headers and remove redundant file name
    comment.
  - #424 Fixed the FreeBSD build failure due to the undefined
    MSG_NOSIGNAL.
  - #420 Setup autotools to read .so version info from a separate
    file
  - #418 Clarify how the autotools build is done on Travis.
* Fri Jan 13 2017 ecsos@opensuse.org
- update to 0.1.4
  * Closed issues:
  - #378 Replace all uses of make_quick_sort with qsort
  - #364 Delete misc_tools.h after replacing its use by qsort.
  - #363 Test against NaCl in addition to libsodium on Travis.
  * Merged PRs:
  - #422 Release v0.1.4.
  - #410 Fix NaCl build: tar was called incorrectly.
  - #409 Clarify that the pass key new function can fail.
  - #407 Don't use git.depth=1 anymore.
  - #404 Issue 404: semicolon not found
  - #403 Warn on -pedantic, don't error yet.
  - #401 Add logging callback to messenger_test.
  - #400 Run windows tests but ignore their failures.
  - #398 Portability Fixes
  - #397 Replace make_quick_sort with qsort
  - #396 Add an OSX build that doesn't run tests.
  - #394 CMake: Add soversion to library files to generate proper
    symlinks
  - #393 Set up autotools build to build against vanilla NaCl.
  - #392 Check that TCP connections aren't dropped in callbacks.
  - #391 Minor simplification in file_seek code.
  - #390 Always kill invalid file transfers when receiving file
    controls.
  - #388 Fix logging condition for IPv6 client timestamp updates.
  - #387 Eliminate dead return statement.
  - #386 Avoid accessing uninitialised memory in net_crypto.
  - #381 Remove TOX_DEBUG and have asserts always enabled.
- update to 0.1.3
  * Closed issues:
  - #347 Implement our own secure memcmp and memzero if libsodium
    isn't available
  * Merged PRs:
  - #395 Revert "Portability fixes"
  - #380 Test a few cmake option combinations before the build.
  - #377 Fix SSL verification in coveralls.
  - #376 Bring back autotools instructions
  - #373 Only fetch 1 revision from git during Travis builds.
  - #369 Integrate with CircleCI to build artifacts in the future
  - #366 Release v0.1.3.
  - #362 Remove .cabal-sandbox option from tox-spectest find
    line.
  - #361 Simplify integration as a third-party lib in cmake
    projects
  - #354 Add secure memcmp and memzero implementation.
  - #324 Do not compile and install DHT_bootstrap if it was
    disabled in configure
  - #297 Portability fixes
- update to 0.1.2
  * Closed issues:
  - #345 Array out of bounds read in "save" function
  - #342 Wrap all libsodium functions we use in toxcore in
    crypto_core.
  - #278 ToxAV use-after-free bug
  * Merged PRs:
  - #355 Release v0.1.2
  - #353 Fix toxav use after free caused by premature MSI
    destruction
  - #346 Avoid array out of bounds read in friend saving.
  - #344 Remove unused get/set salt/key functions from
    toxencryptsave.
  - #343 Wrap all sodium/nacl functions in crypto_core.c.
  - #341 Add test to check if tox_new/tox_kill leaks.
  - #336 Correct TES docs to reflect how many bytes functions
    actually require.
  - #333 Use tox_options_set_* instead of direct member access.
- update to 0.1.1
  * Closed issues:
  - #327 The TOX_VERSION_REQUIRE macro is broken.
  - #221 Option to disable local peer detection
  * Merged PRs:
  - #337 Release v0.1.1
  - #332 Add test for encrypted savedata.
  - #330 Strengthen the note about ABI compatibility in tox.h.
  - #328 Drop the broken TOX_VERSION_REQUIRE macro.
  - #326 Fix unresolved reference in toxencryptsave API docs.
  - #309 Fixed attempt to join detached threads
    (fixes toxav test crash)
  - #306 Add option to disable local peer discovery
- migrate to fork https://github.com/toktok/c-toxcore
  Original was https://github.com/irungentoo/toxcore
* Tue Sep  1 2015 ecsos@opensuse.org
- change location of bootstrap daemon cfg
- change user and group of bootstrap damon
* Thu Aug 27 2015 ecsos@opensuse.org
- update to git from 08.08.2015
- seperate librarys
- insert systemd-services fpr bootstrapd
* Tue Sep 23 2014 ecsos@schirra.net
- remove msi.c_no-return-in-nonvoid-function.patch
* Mon Jun 23 2014 ecsos@schirra.net
- update to git from 23.06.2014
* Sun Feb 23 2014 ecsos@schirra.net
- update to ProjectTox-Core-f219fb4ac1bf60eea3117df4aa8615cd07738a69
* Sat Aug  3 2013 novell@tower-net.de
- Update to ProjectTox-Core-aa78644aed020198f85c97fe63bea7fc88e4a8dc
* Fri Aug  2 2013 novell@tower-net.de
- Modified CMakeLists_curses_ncurses_link_typo.patch
* Fri Aug  2 2013 novell@tower-net.de
- Updated to tox-7379392d80
* Wed Jul 31 2013 novell@tower-net.de
- CMakeLists_curses_ncurses_link_typo.patch fixes a typo to link with libncurses
* Tue Jul 30 2013 novell@tower-net.de
- New tox https://github.com/irungentoo/ProjectTox-Core/commit/b94d9d6765381e0a80f86a85edf45b1fd652a21a
